@@ -1,3 +1,5 @@
+from YOMLogger import YOMLogger
+
 class FormatColumnsError(Exception):
     """
         Exception raised when column of file does not exists.
@@ -9,6 +11,8 @@ class FormatColumnsError(Exception):
     def __init__(self, file, columns):
         self.file = file
         self.columns = columns
+        self.logger = YOMLogger()
+        self.logger.error(self.__str__())
 
     def __str__(self):
         error_message = ''
